pyhsm.basic_cmd.YHSM_NonceResponse

Package pyhsm :: Module basic_cmd :: Class YHSM_NonceResponse |
[frames] | no frames]

# Class YHSM_NonceResponse

Small class to hold response of Nonce_Get command.

Instance Methods
__init__(self, nonce) |
__repr__(self) |

Instance Variables
integer | volatile = `0` Volatile part of nonce
integer | pu_count = `0` Power-up count -- persistent part of nonce
long | nonce_int = `0` Current nonce
string | nonce = `None` Current nonce